# Creates a new output folder if it doesn't already exist
# The folder is created in the same directory as the input file

import os

def folder(screen,logfilename):
     # Create the output directory if necessary
     
    logdir=os.path.dirname(logfilename)
    logname=os.path.basename(logfilename)
    gaussdir=os.path.join(logdir,"gausssum2.1")
    if not os.path.isdir(gaussdir):
        screen.write("Creating new output folder\n")
        os.mkdir(gaussdir)
    else:
        screen.write("Using old output folder\n")

    return gaussdir

  
    
